# This imports all the layers for "now-log-in" into sketch
sketch = Framer.Importer.load "imported/now-log-in"

# Change the framer animation defaults
Framer.Defaults.Animation = {
    curve: 'ease-in-out'
    time: 0.4
}

# --------------------
# Set up our artboards 
# --------------------

# Artboard 1: Login screen 
loginScreen = sketch.LogIn
loginScreen.index = 1

# Artboard 2: Home screen 
homeScreen = sketch.Home
homeScreen.visible = true
homeScreen.rotationY = -90
homeScreen.index = 3

# Artboard 3: Off canvas nav artboard
navScreen = sketch.Navigation
navScreen.visible = true
navScreen.index = 2
navScreen.x = -600
navScreen.opacity = 0

# --------------------
# Login layers 
# --------------------

# Login screen background 
loginBg = sketch.Bg
loginBg.scale = 1.125
loginBg.opacity = 0
loginBg.saturate = 0
loginBg.blur = 5

# Login screen Logo
loginLogo = sketch.Mark
loginLogo.opacity = 0
loginLogo.scale = 1.5
loginLogo.center()

# Login screen form offsets
offset = 110

# Login screen username 
loginUsername = sketch.Username
loginUsername.opacity = 0
loginUsername.y = loginUsername.y-offset

# Login screen password 
loginPassword= sketch.Password
loginPassword.opacity = 0
loginPassword.y = loginPassword.y-offset

# Login screen CTA
loginButton = sketch.CTA
loginButton.opacity = 0
loginButton.y = loginButton.y-offset

# Login screen loading icon
loginLoadingIcon = sketch.Loading
loginLoadingIcon.opacity = 0;

# Login screen help
loginHelpLink = sketch.Help
loginHelpLink.opacity = 0

# Login screen account
loginAccountLink = sketch.Account
loginAccountLink.opacity = 0

# Burger menu open
homeOpenIcon = sketch.Open

# Burger menu close
homeCloseIcon = sketch.Close

# --------------------
# Start our animations
# --------------------

# Login Background
loginBg.animate
	properties:
		opacity: 1
	delay: 0.5

# Login Logo
loginLogo.animate
	properties:
		scale: 1
		opacity: 1
	delay: 0.5
	
loginLogo.animate
	properties:
		y: 200
	delay: 2.5
		
loginBg.animate
	properties:
		saturate: 100
		blur: 0
		scale: 1
	delay: 2.5

# Login username field
loginUsername.animate
	properties:
		opacity: 1
		y: loginUsername.y+offset
	delay: 2.5

# Login passwqord field
loginPassword.animate
	properties:
		opacity: 1
		y: loginPassword.y+offset
	delay: 2.55

# Login Button
loginButton.animate
	properties:
		opacity: 1
		y: loginButton.y+offset
	delay: 2.6
	
# Login account link
loginAccountLink.animate
	properties:
		opacity: 1
	delay: 2.65

#  Login help link
loginHelpLink.animate
	properties:
		opacity: 1
	delay: 2.65

# --------------------
# Attach some events
# --------------------

# When the login button is initially pressed
loginButton.on Events.TouchStart, ->
	# Fade out the button 
	loginButton.animate
		properties:
			opacity: 0.5
		time: 0.125

# After the login button has been released
loginButton.on Events.TouchEnd, ->
	# Show the loading icon
	loginLoadingIcon.animate
		properties:
			opacity: 1
			rotation: 720
		curve: 'linear'
		time: 1.25
	# Flip the login screen
	loginScreen.animate
		properties:
			rotationY: 90
		time: 0.25
		delay: 1.5
	# Flip the home screen		
	homeScreen.animate
		properties:
			rotationY: 0
		delay: 1.75
		time: 0.25		

#  When the burger open icon is pressed
homeOpenIcon.on Events.Click, ->
	# Move the home screen off canvas
	homeScreen.animate
		properties:
			x: 600
			index: 2
# 	Fade out the open icon
	homeOpenIcon.animate
		properties:
			opacity: 0
# Move the nav onto the page
	navScreen.animate
		properties:
			x: 0
			opacity: 1
			index: 3

# When the burger close icon is pressed
homeCloseIcon.on Events.Click, ->	
# 	Move the home screen back to its default position
	homeScreen.animate
		properties:
			x: 0
			index: 3
# 	Show the open icon
	homeOpenIcon.animate
		properties:
			opacity: 1
# Move the nav off canvas
	navScreen.animate
		properties:
			x: -600
			index: 2
			opacity: 0
